'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-0e20a87a.js');
const logger = require('./logger-0e4a4217.js');
const string = require('./string-d17dee1d.js');
const defaultIconPack = require('./default-icon-pack-d94ddba8.js');
const index$1 = require('./index-211dabb8.js');

const SOUNDS = {
  joined: 'https://dyte-uploads.s3.ap-south-1.amazonaws.com/notification_join.mp3',
  message: 'https://dyte-uploads.s3.ap-south-1.amazonaws.com/notification_message.mp3',
};
/**
 * Handles notification sounds in a meeting
 */
class DyteNotificationsAudio {
  constructor() {
    this.audio = document.createElement('audio');
    this.audio.volume = 0.3;
  }
  play(sound, duration = 3000) {
    var _a;
    if (this.playing)
      return;
    this.playing = true;
    this.audio.src = SOUNDS[sound];
    this.audio.volume = 0.3;
    (_a = this.audio.play()) === null || _a === void 0 ? void 0 : _a.catch((err) => {
      logger.loglevel.error('[dyte-notifications] play() failed\n', { sound, duration }, err);
    });
    setTimeout(() => {
      this.playing = false;
    }, duration);
  }
  async setDevice(id) {
    var _a, _b, _c;
    await ((_c = (_b = (_a = this.audio) === null || _a === void 0 ? void 0 : _a.setSinkId) === null || _b === void 0 ? void 0 : _b.call(_a, id)) === null || _c === void 0 ? void 0 : _c.catch((err) => {
      logger.loglevel.error('[dyte-notifications] setSinkId() error\n', err);
    }));
  }
}

let nanoid = (size = 21) => {
  let id = '';
  let bytes = crypto.getRandomValues(new Uint8Array(size));
  while (size--) {
    let byte = bytes[size] & 63;
    if (byte < 36) {
      id += byte.toString(36);
    } else if (byte < 62) {
      id += (byte - 26).toString(36).toUpperCase();
    } else if (byte < 63) {
      id += '_';
    } else {
      id += '-';
    }
  }
  return id
};

const dyteNotificationsCss = ":host{position:absolute;top:var(--dyte-space-4, 16px);right:var(--dyte-space-4, 16px);bottom:var(--dyte-space-4, 16px);left:var(--dyte-space-4, 16px);top:auto;z-index:10;display:flex;flex-direction:column;pointer-events:none}dyte-notification{margin-top:var(--dyte-space-2, 8px)}";

const DyteNotifications = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.notificationPermissions = {
      participant_joined: false,
      participant_left: false,
      chat: false,
    };
    this.soundPermissions = {
      participant_joined: false,
      participant_left: false,
      chat: false,
    };
    /** Language */
    this.t = index$1.useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    this.notifications = [];
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.configChanged(this.config);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    this.participantJoinedListener &&
      this.meeting.participants.joined.removeListener('participantJoined', this.participantJoinedListener);
    this.participantLeftListener &&
      this.meeting.participants.joined.removeListener('participantLeft', this.participantLeftListener);
    this.chatUpdateListener &&
      this.meeting.chat.removeListener('chatUpdate', this.chatUpdateListener);
    this.networkUpdateListener &&
      this.meeting.self.removeListener('disconnected', this.networkUpdateListener);
    this.networkUpdateListener &&
      this.meeting.self.removeListener('connected', this.networkUpdateListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.audio = new DyteNotificationsAudio();
      this.participantJoinedListener = (peer) => {
        if (this.notificationPermissions.participant_joined) {
          this.add({
            id: `${peer.id}-joined`,
            message: `${string.formatName(peer.name)} just joined`,
            image: peer.picture,
            duration: 2100,
          });
        }
        if (this.soundPermissions.participant_joined) {
          this.audio.play('joined');
        }
      };
      this.participantLeftListener = (peer) => {
        if (this.notificationPermissions.participant_left) {
          this.add({
            id: `${peer.id}-left`,
            message: `${string.formatName(peer.name)} left`,
            image: peer.picture,
            duration: 2100,
          });
        }
      };
      this.chatUpdateListener = ({ message }) => {
        if (message != null) {
          if (message.userId === meeting.self.id) {
            return;
          }
          if (message.type === 'text') {
            if (this.notificationPermissions.chat) {
              this.add({
                id: `message-${nanoid(7)}`,
                icon: this.iconPack.chat,
                message: `${message.displayName}: ${string.shorten(message.message, 20)}`,
                duration: 2000,
              });
            }
            if (this.soundPermissions.chat) {
              this.audio.play('message');
            }
          }
        }
      };
      this.deviceUpdateListener = ({ device, preview }) => {
        if (preview)
          return;
        if (device.kind === 'audiooutput') {
          this.audio.setDevice(device.deviceId);
        }
      };
      this.networkUpdateListener = ({ event }) => {
        this.remove('network');
        let reconnectDuration;
        if (event === 'disconnected') {
          reconnectDuration = 20000;
          this.add({
            id: 'network',
            icon: this.iconPack.disconnected,
            message: this.t('Connection lost. Trying to reconnect...'),
            duration: reconnectDuration,
          });
          this.states.disconnectTimeout = setTimeout(() => {
            var _a;
            this.states.roomLeftState = 'disconnected';
            (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.leaveRoom();
          }, reconnectDuration);
        }
        else if (event === 'connected') {
          reconnectDuration = 3000;
          this.add({
            id: `network`,
            icon: this.iconPack.wifi,
            message: this.t('Connection restored'),
            duration: reconnectDuration,
          });
          clearTimeout(this.states.disconnectTimeout);
        }
      };
      const currentDevices = meeting.self.getCurrentDevices();
      if (currentDevices.speaker != null) {
        this.audio.setDevice(currentDevices.speaker.deviceId);
      }
      meeting.participants.joined.addListener('participantJoined', this.participantJoinedListener);
      meeting.participants.joined.addListener('participantLeft', this.participantLeftListener);
      meeting.chat.addListener('chatUpdate', this.chatUpdateListener);
      meeting.self.addListener('deviceUpdate', this.deviceUpdateListener);
      meeting.meta.addListener('disconnected', () => this.networkUpdateListener({ event: 'disconnected' }));
      meeting.meta.addListener('connected', () => this.networkUpdateListener({ event: 'connected' }));
    }
  }
  configChanged(config) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    if (config != null) {
      this.notificationPermissions.participant_joined =
        (_b = (_a = config.config) === null || _a === void 0 ? void 0 : _a.notifications) === null || _b === void 0 ? void 0 : _b.includes('participant_joined');
      this.notificationPermissions.participant_left =
        (_d = (_c = config.config) === null || _c === void 0 ? void 0 : _c.notifications) === null || _d === void 0 ? void 0 : _d.includes('participant_left');
      this.notificationPermissions.chat = (_f = (_e = config.config) === null || _e === void 0 ? void 0 : _e.notifications) === null || _f === void 0 ? void 0 : _f.includes('chat');
      this.soundPermissions.participant_joined =
        (_h = (_g = config.config) === null || _g === void 0 ? void 0 : _g.notification_sounds) === null || _h === void 0 ? void 0 : _h.includes('participant_joined');
      this.soundPermissions.participant_left =
        (_k = (_j = config.config) === null || _j === void 0 ? void 0 : _j.notification_sounds) === null || _k === void 0 ? void 0 : _k.includes('participant_left');
      this.soundPermissions.chat = (_m = (_l = config.config) === null || _l === void 0 ? void 0 : _l.notification_sounds) === null || _m === void 0 ? void 0 : _m.includes('chat');
    }
  }
  statesUpdate(states) {
    var _a, _b;
    if (states != null) {
      const notificationSoundsEnabled = !states.prefs.muteNotificationSounds;
      const configSoundPermission = (_b = (_a = this.config) === null || _a === void 0 ? void 0 : _a.config) === null || _b === void 0 ? void 0 : _b.notification_sounds;
      for (const permission in this.soundPermissions) {
        if (configSoundPermission === null || configSoundPermission === void 0 ? void 0 : configSoundPermission.includes(permission)) {
          this.soundPermissions[permission] = notificationSoundsEnabled;
        }
      }
    }
  }
  add(notification) {
    // show notifications only if tab is in focus
    if (document.visibilityState === 'visible') {
      // adds new notification to start of array so they appear at the bottom
      this.notifications = [...this.notifications, notification];
    }
  }
  remove(id) {
    this.notifications = this.notifications.filter((notification) => notification.id !== id);
  }
  handleDismiss(e) {
    e.stopPropagation();
    const id = e.detail;
    const el = this.host.shadowRoot.querySelector(`[data-id="${id}"]`);
    if (el != null) {
      // exit animation
      el.classList.add('exit');
    }
    setTimeout(() => {
      index.writeTask(() => {
        this.remove(id);
      });
    }, 400);
  }
  render() {
    return (index.h(index.Host, null, this.notifications.map((notification) => (index.h("dyte-notification", { size: this.size, key: notification.id, "data-id": notification.id, notification: notification, onDismiss: (e) => this.handleDismiss(e) })))));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "config": ["configChanged"],
    "states": ["statesUpdate"]
  }; }
};
DyteNotifications.style = dyteNotificationsCss;

exports.dyte_notifications = DyteNotifications;
