import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
export class DyteGridPagination {
  constructor() {
    /** Variant */
    this.variant = 'rounded';
    /** Icon Pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.page = 1;
    this.participantCount = 1;
    this.pageCount = 0;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    if (this.pageChangedListener != null) {
      this.meeting.participants.removeListener('viewModeChanged', this.pageChangedListener);
      this.meeting.participants.removeListener('pageChanged', this.pageChangedListener);
    }
    if (this.participantUpdateListener != null) {
      this.meeting.participants.joined.removeListener('participantJoined', this.participantUpdateListener);
      this.meeting.participants.joined.removeListener('participantLeft', this.participantUpdateListener);
    }
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.pageCount = meeting.participants.pageCount;
      this.pageChangedListener = ({ currentPage }) => {
        this.pageCount = meeting.participants.pageCount;
        this.page = currentPage !== 0 ? currentPage : 1;
      };
      this.participantUpdateListener = () => {
        this.participantCount =
          meeting.participants.joined.size + (meeting.self.roomJoined ? 1 : 0);
        this.pageCount = meeting.participants.pageCount;
      };
      meeting.participants.addListener('viewModeChanged', this.pageChangedListener);
      meeting.participants.addListener('pageChanged', this.pageChangedListener);
      meeting.participants.joined.addListener('participantJoined', this.participantUpdateListener);
      meeting.participants.joined.addListener('participantLeft', this.participantUpdateListener);
      this.participantUpdateListener();
    }
  }
  prevPage() {
    const meeting = this.meeting;
    if (meeting == null)
      return;
    if (this.page > 1) {
      meeting.participants.setPage((this.page -= 1));
    }
    else if (this.page === 1 && meeting.participants.viewMode === 'PAGINATED') {
      meeting.participants.setViewMode('ACTIVE_GRID').then(() => {
        this.pageCount = 0;
      });
    }
  }
  nextPage() {
    var _a;
    const meeting = this.meeting;
    if (meeting == null)
      return;
    if (this.page > 0 && this.page < this.pageCount) {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.setPage((this.page += 1));
    }
    else if (this.pageCount === 0 && meeting.participants.viewMode === 'ACTIVE_GRID') {
      meeting.participants.setViewMode('PAGINATED').then(() => {
        this.pageCount = meeting.participants.pageCount;
      });
    }
  }
  render() {
    return (h(Host, null,
      h("dyte-button", { class: "prev", variant: "outline", kind: "icon", disabled: this.pageCount === 0, onClick: () => this.prevPage(), "aria-label": this.t('Previous Page') },
        h("dyte-icon", { icon: this.iconPack.chevron_left })),
      this.variant !== 'grid' && (h("div", { class: "center" },
        h("span", { class: "page" }, this.pageCount === 0 ? (h("dyte-tooltip", { label: this.t('Auto Layout') },
          h("dyte-button", { kind: "icon", class: "auto" },
            h("dyte-icon", { icon: this.iconPack.wand })))) : (this.page)),
        this.pageCount !== 0 && [
          h("span", { class: "slash" }, "/"),
          h("span", { class: "pages" }, this.pageCount),
        ])),
      this.variant === 'grid' && this.pageCount > 0 && (h("div", { class: "dots" }, [...Array(this.pageCount)].map((_, index) => (h("div", { key: `dot-${index}`, class: { dot: true, active: index + 1 === this.page } }))))),
      h("dyte-button", { class: "next", variant: "outline", kind: "icon", disabled: this.page !== 0 && this.page === this.pageCount, onClick: () => this.nextPage(), "aria-label": this.t('Next Page') },
        h("dyte-icon", { icon: this.iconPack.chevron_right, tabIndex: -1, "aria-hidden": true }))));
  }
  static get is() { return "dyte-grid-pagination"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-grid-pagination.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-grid-pagination.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States"
      }
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "GridPaginationVariants",
        "resolved": "\"grid\" | \"rounded\" | \"solid\"",
        "references": {
          "GridPaginationVariants": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Variant"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'rounded'"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon Pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "page": {},
    "participantCount": {},
    "pageCount": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
