import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
export class DytePlugins {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.plugins = [];
    this.canStartPlugins = false;
    this.canClosePlugin = false;
    this.activatedPluginsId = [];
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    this.meeting.plugins.all.removeListener('stateUpdate', this.updateActivePlugins);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canStartPlugins = meeting.self.permissions.plugins.canStart;
      this.canClosePlugin = meeting.self.permissions.plugins.canClose;
      this.plugins = meeting.plugins.all.toArray();
      this.updateActivePlugins = () => {
        this.activatedPluginsId = meeting.plugins.active.toArray().map((p) => p.id);
      };
      this.updateActivePlugins();
      meeting.plugins.all.addListener('stateUpdate', this.updateActivePlugins);
    }
  }
  render() {
    return (h(Host, null,
      h("ul", { class: "scrollbar" }, this.plugins.map((plugin) => (h("li", { key: plugin.name, class: "plugin" },
        h("div", { class: "metadata" },
          h("img", { src: plugin.picture }),
          h("div", { class: "name" }, plugin.name)),
        !this.activatedPluginsId.includes(plugin.id) && this.canStartPlugins && (h("div", { class: "buttons" },
          h("dyte-button", { kind: "icon", onClick: () => {
              plugin.activate();
            }, "aria-label": `${this.t('Activate')} ${plugin.name}` },
            h("dyte-icon", { icon: this.iconPack.rocket, tabIndex: -1, "aria-hidden": true })))),
        this.activatedPluginsId.includes(plugin.id) && this.canClosePlugin && (h("div", { class: "buttons" },
          h("dyte-button", { kind: "icon", onClick: () => {
              plugin.deactivate();
            }, "aria-label": `${this.t('Close')} ${plugin.name}` },
            h("dyte-icon", { icon: this.iconPack.dismiss, tabIndex: -1, "aria-hidden": true }))))))))));
  }
  static get is() { return "dyte-plugins"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-plugins.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-plugins.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "plugins": {},
    "canStartPlugins": {},
    "canClosePlugin": {},
    "activatedPluginsId": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
