import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { shorten } from '../../utils/string';
import { defaultConfig } from '../../lib/default-ui-config';
import { Render } from '../../lib/render';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import gracefulStorage from '../../utils/graceful-storage';
export class DyteSetupScreen {
  constructor() {
    /** Config object */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.isJoining = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      // NOTE(roerohan): Set display name from local storage if available.
      // If the name is '', `use meeting.self.name`.
      this.displayName = gracefulStorage.getItem('dyte-display-name') || meeting.self.name;
      // NOTE(roerohan): This is to update the name in the peer-view component,
      // since it uses `meeting.self.name`.
      meeting.self.setName(this.displayName);
    }
  }
  join() {
    var _a;
    if (this.displayName !== '') {
      this.isJoining = true;
      this.meeting.self.setName(this.displayName);
      gracefulStorage.setItem('dyte-display-name', this.displayName);
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.joinRoom();
    }
  }
  render() {
    var _a, _b;
    const disabled = this.displayName.trim() === '';
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null,
      h("div", { class: "ctr" },
        h("div", { class: "left" },
          h(Render, { element: "dyte-peer-view", defaults: defaults, props: { peer: (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self }, childProps: { peer: (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self }, deepProps: true }),
          h("div", { class: "controls" },
            h("dyte-mic-toggle", { size: "sm", meeting: this.meeting }),
            h("dyte-camera-toggle", { size: "sm", meeting: this.meeting }))),
        h("div", { class: "right" },
          h("h1", null, this.displayName.trim() === ''
            ? 'Hello there!'
            : `Hello ${shorten(this.displayName, 20)}!`),
          h("input", { placeholder: "Your name", value: this.displayName, onInput: (e) => {
              this.displayName = e.target.value;
            }, onKeyDown: (e) => {
              if (e.key === 'Enter') {
                this.join();
              }
            } }),
          h("dyte-button", { onClick: () => this.join(), disabled: disabled }, this.isJoining ? h("dyte-spinner", null) : 'Join')))));
  }
  static get is() { return "dyte-setup-screen"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-setup-screen.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-setup-screen.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config object"
      },
      "defaultValue": "defaultConfig"
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "displayName": {},
    "isJoining": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
