import { Component, Host, h, Prop } from '@stencil/core';
import { hasOnlyEmojis } from '../../utils/string';
import { ChatHead } from '../dyte-chat/components/ChatHead';
import { TextMessageView } from './components/TextMessage';
export class DyteTextMessage {
  constructor() {
    /** Date object of now, to calculate distance between dates */
    this.now = new Date();
    /** Whether the message is continued by same user */
    this.isContinued = false;
  }
  render() {
    return (h(Host, null,
      !this.isContinued && (h(ChatHead, { name: this.message.displayName, time: this.message.time, now: this.now })),
      h("div", { class: "body" },
        h("div", { class: { text: true, emoji: hasOnlyEmojis(this.message.message) } },
          h(TextMessageView, { message: this.message.message })))));
  }
  static get is() { return "dyte-text-message"; }
  static get properties() { return {
    "message": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "TextMessage",
        "resolved": "TextMessage",
        "references": {
          "TextMessage": {
            "location": "import",
            "path": "@dyte-in/client-core/types/client/DyteChat"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text message object"
      }
    },
    "now": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Date",
        "resolved": "Date",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Date object of now, to calculate distance between dates"
      },
      "defaultValue": "new Date()"
    },
    "isContinued": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the message is continued by same user"
      },
      "attribute": "is-continued",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
}
