import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { f as formatName } from './string.js';

const getInitials = (name) => {
  return name
    .split(' ')
    .map((part) => part[0])
    .join('')
    .toUpperCase();
};

const dyteAvatarCss = ":host{display:flex;height:var(--dyte-space-20, 80px);width:var(--dyte-space-20, 80px);align-items:center;justify-content:center;font-family:var(--dyte-font-family, sans-serif);font-size:28px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-video-bg, 24 24 24) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));overflow:hidden;border-radius:9999px}dyte-icon{height:50%;width:50%}.initials{display:flex;height:100%;width:100%;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}.image{display:flex;height:100%;width:100%;align-items:center;justify-content:center}.image img{display:none;height:100%;width:100%;-o-object-fit:cover;object-fit:cover}.image img.loaded{display:block}:host([type='hexagon']){border-radius:var(--dyte-border-radius-none, 0);-webkit-clip-path:polygon(50% 0, 95% 25%, 95% 75%, 50% 100%, 5% 75%, 5% 25%);clip-path:polygon(50% 0, 95% 25%, 95% 75%, 50% 100%, 5% 75%, 5% 25%)}:host([size='sm']){height:var(--dyte-space-12, 48px);width:var(--dyte-space-12, 48px);font-size:20px}:host([size='md']){height:var(--dyte-space-16, 64px);width:var(--dyte-space-16, 64px)}:host([size='lg']){height:var(--dyte-space-24, 96px);width:var(--dyte-space-24, 96px)}";

const DyteAvatar = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Avatar type */
    this.type = 'circular';
    /** Icon pack */
    this.iconPack = defaultIconPack;
  }
  render() {
    const name = formatName(this.peer.name);
    const initials = getInitials(name);
    return (h(Host, null, h("div", { class: "initials" }, initials)));
  }
  static get style() { return dyteAvatarCss; }
}, [1, "dyte-avatar", {
    "peer": [16],
    "type": [513],
    "size": [513],
    "iconPack": [16]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-avatar"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-avatar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteAvatar);
      }
      break;
  } });
}

export { DyteAvatar as D, defineCustomElement as d };
