import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$4 } from './dyte-button2.js';
import { d as defineCustomElement$3 } from './dyte-icon2.js';
import { d as defineCustomElement$2 } from './dyte-tooltip2.js';

const dyteGridPaginationCss = ":host{margin-left:var(--dyte-space-4, 16px);margin-right:var(--dyte-space-4, 16px);display:flex;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;align-items:center;font-family:var(--dyte-font-family, sans-serif);font-size:16px}dyte-button{--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.center{margin-left:var(--dyte-space-2, 8px);margin-right:var(--dyte-space-2, 8px);color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}.center .page{color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88))}.center .slash{margin-left:var(--dyte-space-0\\.5, 2px);margin-right:var(--dyte-space-0\\.5, 2px)}.center .pages{align-self:flex-end;font-size:12px}:host([variant='rounded']){overflow:hidden;border-radius:9999px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity))}:host([variant='rounded']) dyte-button{border-radius:9999px;border-width:var(--dyte-border-width-none, 0);border-style:none;background-color:transparent;color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64));transition-property:color, background-color, border-color, fill, stroke, -webkit-text-decoration-color;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, -webkit-text-decoration-color;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}:host([variant='rounded']) dyte-button:not([disabled]):hover{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}:host([variant='rounded']) dyte-button:not([disabled]):focus{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}:host([variant='grid']){margin-left:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-0, 0px)}:host([variant='grid']) dyte-button{position:absolute;top:50%;height:var(--dyte-space-20, 80px);width:var(--dyte-space-20, 80px);opacity:0.2;transition-property:color, background-color, border-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}:host([variant='grid']) dyte-button:hover{opacity:1}:host([variant='grid']) dyte-button{transform:translateY(-50%)}:host([variant='grid']) dyte-button.prev{left:var(--dyte-space-0, 0px);border-top-right-radius:9999px;border-bottom-right-radius:9999px}:host([variant='grid']) dyte-button.next{right:var(--dyte-space-0, 0px);border-top-left-radius:9999px;border-bottom-left-radius:9999px}:host([variant='grid']) dyte-button.auto{left:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);border-top-right-radius:9999px;border-bottom-right-radius:9999px}:host([variant='grid']) .dots{position:absolute;left:50%;bottom:var(--dyte-space-3, 12px);display:flex;align-items:center;transform:translateX(-50%)}:host([variant='grid']) .dots .dot{margin-right:var(--dyte-space-2, 8px);height:var(--dyte-space-2, 8px);width:var(--dyte-space-2, 8px);cursor:pointer;border-radius:9999px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity))}:host([variant='grid']) .dots .dot:last-child{margin-right:var(--dyte-space-0, 0px)}:host([variant='grid']) .dots .dot.active{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}:host([variant='grid'][size='sm']) dyte-button{height:var(--dyte-space-14, 56px);width:var(--dyte-space-14, 56px);opacity:0.1}";

const DyteGridPagination$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Variant */
    this.variant = 'rounded';
    /** Icon Pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.page = 1;
    this.participantCount = 1;
    this.pageCount = 0;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    if (this.pageChangedListener != null) {
      this.meeting.participants.removeListener('viewModeChanged', this.pageChangedListener);
      this.meeting.participants.removeListener('pageChanged', this.pageChangedListener);
    }
    if (this.participantUpdateListener != null) {
      this.meeting.participants.joined.removeListener('participantJoined', this.participantUpdateListener);
      this.meeting.participants.joined.removeListener('participantLeft', this.participantUpdateListener);
    }
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.pageCount = meeting.participants.pageCount;
      this.pageChangedListener = ({ currentPage }) => {
        this.pageCount = meeting.participants.pageCount;
        this.page = currentPage !== 0 ? currentPage : 1;
      };
      this.participantUpdateListener = () => {
        this.participantCount =
          meeting.participants.joined.size + (meeting.self.roomJoined ? 1 : 0);
        this.pageCount = meeting.participants.pageCount;
      };
      meeting.participants.addListener('viewModeChanged', this.pageChangedListener);
      meeting.participants.addListener('pageChanged', this.pageChangedListener);
      meeting.participants.joined.addListener('participantJoined', this.participantUpdateListener);
      meeting.participants.joined.addListener('participantLeft', this.participantUpdateListener);
      this.participantUpdateListener();
    }
  }
  prevPage() {
    const meeting = this.meeting;
    if (meeting == null)
      return;
    if (this.page > 1) {
      meeting.participants.setPage((this.page -= 1));
    }
    else if (this.page === 1 && meeting.participants.viewMode === 'PAGINATED') {
      meeting.participants.setViewMode('ACTIVE_GRID').then(() => {
        this.pageCount = 0;
      });
    }
  }
  nextPage() {
    var _a;
    const meeting = this.meeting;
    if (meeting == null)
      return;
    if (this.page > 0 && this.page < this.pageCount) {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.setPage((this.page += 1));
    }
    else if (this.pageCount === 0 && meeting.participants.viewMode === 'ACTIVE_GRID') {
      meeting.participants.setViewMode('PAGINATED').then(() => {
        this.pageCount = meeting.participants.pageCount;
      });
    }
  }
  render() {
    return (h(Host, null, h("dyte-button", { class: "prev", variant: "outline", kind: "icon", disabled: this.pageCount === 0, onClick: () => this.prevPage(), "aria-label": this.t('Previous Page') }, h("dyte-icon", { icon: this.iconPack.chevron_left })), this.variant !== 'grid' && (h("div", { class: "center" }, h("span", { class: "page" }, this.pageCount === 0 ? (h("dyte-tooltip", { label: this.t('Auto Layout') }, h("dyte-button", { kind: "icon", class: "auto" }, h("dyte-icon", { icon: this.iconPack.wand })))) : (this.page)), this.pageCount !== 0 && [
      h("span", { class: "slash" }, "/"),
      h("span", { class: "pages" }, this.pageCount),
    ])), this.variant === 'grid' && this.pageCount > 0 && (h("div", { class: "dots" }, [...Array(this.pageCount)].map((_, index) => (h("div", { key: `dot-${index}`, class: { dot: true, active: index + 1 === this.page } }))))), h("dyte-button", { class: "next", variant: "outline", kind: "icon", disabled: this.page !== 0 && this.page === this.pageCount, onClick: () => this.nextPage(), "aria-label": this.t('Next Page') }, h("dyte-icon", { icon: this.iconPack.chevron_right, tabIndex: -1, "aria-hidden": true }))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteGridPaginationCss; }
}, [1, "dyte-grid-pagination", {
    "meeting": [16],
    "states": [16],
    "variant": [513],
    "iconPack": [16],
    "t": [16],
    "page": [32],
    "participantCount": [32],
    "pageCount": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-grid-pagination", "dyte-button", "dyte-icon", "dyte-tooltip"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-grid-pagination":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteGridPagination$1);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-tooltip":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteGridPagination = DyteGridPagination$1;
const defineCustomElement = defineCustomElement$1;

export { DyteGridPagination, defineCustomElement };
