import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$3 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';

const dyteParticipantsToggleCss = ":host{display:block}";

const DyteParticipantsToggle$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.participantsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
  }
  statesChanged(states) {
    if (states != null) {
      this.participantsActive = this.states.activeSidebar && this.states.sidebar === 'participants';
    }
  }
  toggleParticipantsTab() {
    this.participantsActive = !(this.states.activeSidebar && this.states.sidebar === 'participants');
    this.stateUpdate.emit({
      activeSidebar: this.participantsActive,
      sidebar: this.participantsActive ? 'participants' : 'none',
    });
  }
  render() {
    const text = this.t('participants');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { class: { active: this.participantsActive }, size: this.size, onClick: () => this.toggleParticipantsTab(), icon: this.iconPack.participants, label: text })));
  }
  static get watchers() { return {
    "states": ["statesChanged"]
  }; }
  static get style() { return dyteParticipantsToggleCss; }
}, [1, "dyte-participants-toggle", {
    "meeting": [16],
    "states": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "participantsActive": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-participants-toggle", "dyte-controlbar-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-participants-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteParticipantsToggle$1);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteParticipantsToggle = DyteParticipantsToggle$1;
const defineCustomElement = defineCustomElement$1;

export { DyteParticipantsToggle, defineCustomElement };
