import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { l as loglevel } from './logger.js';
import { d as defineCustomElement$3 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';

const dyteScreenShareToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const deviceCanScreenShare = () => {
  return (typeof navigator !== 'undefined' &&
    typeof navigator.mediaDevices !== 'undefined' &&
    'getDisplayMedia' in navigator.mediaDevices);
};
const DyteScreenShareToggle$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.screenShareEnabled = false;
    this.canScreenShare = false;
  }
  connectedCallback() {
    if (!deviceCanScreenShare()) {
      loglevel.error('[dyte-screenshare-toggle] Device does not support screensharing.');
    }
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('screenShareUpdate', this.screenShareListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canScreenShare =
        deviceCanScreenShare() && meeting.self.permissions.produceScreenshare.allow;
      this.screenShareEnabled = self.screenShareEnabled;
      this.screenShareListener = ({ screenShareEnabled }) => {
        this.screenShareEnabled = screenShareEnabled;
      };
      self.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  toggleScreenShare() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canScreenShare) {
      return;
    }
    if (self.screenShareEnabled) {
      self.disableScreenShare();
    }
    else {
      self.enableScreenShare();
    }
  }
  render() {
    if (!this.canScreenShare) {
      return null;
    }
    const text = this.t(this.screenShareEnabled ? 'share_screen_stop' : 'share_screen_start');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': this.screenShareEnabled,
      }, onClick: () => this.toggleScreenShare(), icon: this.screenShareEnabled
        ? this.iconPack.share_screen_stop
        : this.iconPack.share_screen_start, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteScreenShareToggleCss; }
}, [1, "dyte-screen-share-toggle", {
    "meeting": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "screenShareEnabled": [32],
    "canScreenShare": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-screen-share-toggle", "dyte-controlbar-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-screen-share-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteScreenShareToggle$1);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteScreenShareToggle = DyteScreenShareToggle$1;
const defineCustomElement = defineCustomElement$1;

export { DyteScreenShareToggle, defineCustomElement };
