import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$g } from './dyte-avatar2.js';
import { d as defineCustomElement$f } from './dyte-button2.js';
import { d as defineCustomElement$e } from './dyte-chat2.js';
import { d as defineCustomElement$d } from './dyte-file-message2.js';
import { d as defineCustomElement$c } from './dyte-icon2.js';
import { d as defineCustomElement$b } from './dyte-image-message2.js';
import { d as defineCustomElement$a } from './dyte-menu2.js';
import { d as defineCustomElement$9 } from './dyte-menu-item2.js';
import { d as defineCustomElement$8 } from './dyte-menu-list2.js';
import { d as defineCustomElement$7 } from './dyte-participant2.js';
import { d as defineCustomElement$6 } from './dyte-participants2.js';
import { d as defineCustomElement$5 } from './dyte-plugins2.js';
import { d as defineCustomElement$4 } from './dyte-spinner2.js';
import { d as defineCustomElement$3 } from './dyte-text-message2.js';
import { d as defineCustomElement$2 } from './dyte-tooltip2.js';

const dyteSidebarCss = ":host{position:relative;box-sizing:border-box;display:block;width:100%;max-width:var(--dyte-space-80, 320px);overflow:hidden;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));display:flex;flex-direction:column}.close{display:none;position:absolute;top:var(--dyte-space-3, 12px);left:var(--dyte-space-3, 12px);height:var(--dyte-space-6, 24px);width:var(--dyte-space-6, 24px);cursor:pointer;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88))}.title{margin:var(--dyte-space-0, 0px);margin-top:var(--dyte-space-3, 12px);margin-bottom:var(--dyte-space-3, 12px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;text-align:center;font-size:16px;font-weight:400}#mobile-header{margin-top:var(--dyte-space-2, 8px);display:flex;align-items:center;justify-content:space-evenly;border-bottom:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}#mobile-header dyte-button{height:var(--dyte-space-10, 40px);font-size:14px;color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76));border-bottom:var(--dyte-border-width-md, 2px) solid transparent}#mobile-header dyte-button.active{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-400, 53 110 253) / var(--tw-text-opacity));border-color:rgb(var(--dyte-colors-brand-400, 53 110 253))}dyte-chat,dyte-participants,dyte-plugins{flex:1}:host([view='sidebar']){margin-left:var(--dyte-space-2, 8px);margin-right:var(--dyte-space-2, 8px);border-radius:var(--dyte-border-radius-lg, 12px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity))}:host([view='sidebar']) .close{display:inline-flex}:host([view='full-screen']){position:absolute;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);z-index:30;max-width:100%;border:none}:host([view='full-screen']) .close{display:block}";

const DyteSidebar$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** View type */
    this.view = 'default';
    this.tab = 'none';
  }
  connectedCallback() {
    this.viewChanged(this.view);
    this.statesChanged(this.states);
  }
  disconnectedCallback() {
    this.keydownListener && document.removeEventListener('keydown', this.keydownListener);
  }
  statesChanged(states) {
    if (states != null) {
      if (states.sidebar) {
        this.tab = states.sidebar;
      }
    }
  }
  viewChanged(view) {
    if (view === 'full-screen') {
      this.keydownListener = (e) => {
        if (e.key === 'Escape') {
          this.close();
        }
      };
      document.addEventListener('keydown', this.keydownListener);
    }
  }
  close() {
    this.stateUpdate.emit({ activeSidebar: false, sidebar: 'none' });
  }
  render() {
    const defaults = { meeting: this.meeting, size: this.size, config: this.config };
    return (h(Host, { style: { display: this.tab === 'none' ? 'none' : undefined } }, this.view === 'full-screen' && [
      h("h3", { class: "title" }, this.t('About Call')),
      h("div", { id: "mobile-header" }, h("dyte-button", { variant: "neutral", class: { active: this.tab === 'chat' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'chat' });
        } }, "Chat"), h("dyte-button", { variant: "neutral", class: { active: this.tab === 'participants' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'participants' });
        } }, "Participants"), h("dyte-button", { variant: "neutral", class: { active: this.tab === 'plugins' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'plugins' });
        } }, "Plugins")),
    ], h("dyte-button", { variant: "ghost", kind: "icon", class: "close", onClick: () => this.close(), "aria-label": this.t('Close') }, h("dyte-icon", { icon: this.iconPack.dismiss })), this.view !== 'full-screen' && h("h3", { class: "title" }, this.t(this.tab)), this.tab === 'chat' && h("dyte-chat", Object.assign({}, defaults)), this.tab === 'participants' && h("dyte-participants", Object.assign({}, defaults)), this.tab === 'plugins' && h("dyte-plugins", Object.assign({}, defaults))));
  }
  static get watchers() { return {
    "states": ["statesChanged"],
    "view": ["viewChanged"]
  }; }
  static get style() { return dyteSidebarCss; }
}, [1, "dyte-sidebar", {
    "meeting": [16],
    "states": [16],
    "config": [16],
    "iconPack": [16],
    "t": [16],
    "size": [513],
    "view": [513],
    "tab": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-sidebar", "dyte-avatar", "dyte-button", "dyte-chat", "dyte-file-message", "dyte-icon", "dyte-image-message", "dyte-menu", "dyte-menu-item", "dyte-menu-list", "dyte-participant", "dyte-participants", "dyte-plugins", "dyte-spinner", "dyte-text-message", "dyte-tooltip"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-sidebar":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteSidebar$1);
      }
      break;
    case "dyte-avatar":
      if (!customElements.get(tagName)) {
        defineCustomElement$g();
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$f();
      }
      break;
    case "dyte-chat":
      if (!customElements.get(tagName)) {
        defineCustomElement$e();
      }
      break;
    case "dyte-file-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "dyte-image-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "dyte-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "dyte-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "dyte-menu-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "dyte-participant":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "dyte-participants":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "dyte-plugins":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "dyte-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-text-message":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-tooltip":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteSidebar = DyteSidebar$1;
const defineCustomElement = defineCustomElement$1;

export { DyteSidebar, defineCustomElement };
