import { r as registerInstance, h, H as Host } from './index-da7bf46b.js';
import { d as defaultConfig, R as Render } from './index-560ccbe9.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';
import { f as formatName, s as shorten } from './string-739d5cc6.js';

const dyteFullGridCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{display:flex;height:100%;width:100%;padding:var(--dyte-space-2, 8px)}:host main{display:flex;flex:1 1 0%;flex-direction:row-reverse}:host main .active-tab{margin-left:var(--dyte-space-3, 12px);margin-right:var(--dyte-space-3, 12px);display:flex;flex:1 1 0%;flex-direction:column}:host main .active-tab>*{height:100%;width:100%}:host main .switcher{display:flex;height:100%;width:var(--dyte-space-20, 80px);flex-direction:column}:host main .switcher .list{display:flex;flex:1 1 0%;flex-direction:column;align-items:center;overflow-y:auto;flex-basis:0}:host main .switcher .list>*{margin-bottom:var(--dyte-space-2, 8px)}:host main .switcher .list>*:last-child{margin-bottom:var(--dyte-space-0, 0px)}:host main .switcher dyte-button{height:var(--dyte-space-16, 64px);width:var(--dyte-space-16, 64px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}:host main .switcher dyte-button dyte-icon{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px)}:host main .switcher dyte-button img{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px)}:host main .switcher dyte-button .name{font-size:12px;overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:1}:host main .switcher dyte-button.active{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}:host aside{display:flex;height:100%;width:var(--dyte-space-72, 288px);flex-direction:column}:host aside .list{display:flex;flex:1 1 0%;flex-direction:column;overflow-y:scroll;padding-right:var(--dyte-space-1, 4px);flex-basis:0}:host aside dyte-peer-view{margin-bottom:var(--dyte-space-2, 8px);height:auto;width:100%;flex-shrink:0}:host aside dyte-peer-view:last-child{margin-bottom:var(--dyte-space-0, 0px)}:host([size='sm']){flex-direction:column}:host([size='sm']) main{flex-shrink:0;flex-direction:column;flex-basis:0}:host([size='sm']) main .active-tab{margin-left:var(--dyte-space-1, 4px);margin-right:var(--dyte-space-1, 4px)}:host([size='sm']) main .switcher{margin-top:var(--dyte-space-2, 8px);margin-bottom:var(--dyte-space-2, 8px);margin-left:var(--dyte-space-1, 4px);margin-right:var(--dyte-space-1, 4px);height:var(--dyte-space-20, 80px);width:auto;flex-direction:row}:host([size='sm']) main .switcher .list{margin-left:auto;margin-right:auto;width:var(--dyte-space-10, 40px);flex-direction:row;align-items:center;overflow-x:auto;flex-basis:1}:host([size='sm']) main .switcher .list dyte-button{margin-bottom:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-2, 8px);height:var(--dyte-space-14, 56px);width:var(--dyte-space-14, 56px);flex-shrink:0}:host([size='sm']) main .switcher .list dyte-button:last-child{margin-right:var(--dyte-space-0, 0px)}:host([size='sm']) aside{height:var(--dyte-space-32, 128px);width:auto;flex-direction:row}:host([size='sm']) aside .list{display:flex;width:var(--dyte-space-10, 40px);flex-direction:row;overflow-x:auto;padding-right:var(--dyte-space-0, 0px)}:host([size='sm']) aside .list dyte-peer-view{margin-bottom:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-2, 8px);height:100%;width:auto}:host([size='sm']) aside .list dyte-peer-view:last-child{margin-right:var(--dyte-space-0, 0px)}.col-center{display:flex;flex:1 1 0%;flex-direction:column;align-items:center;justify-content:center}.col-center>*:last-child{margin-top:var(--dyte-space-1, 4px)}.col-center img{border-radius:var(--dyte-border-radius-sm, 4px)}";

const DyteFullGrid = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Active Peers */
    this.peers = [];
    /** Screenshare Peers */
    this.screenSharePeers = [];
    /** Active plugins */
    this.plugins = [];
    /** Aspect ratio */
    this.aspectRatio = '16:9';
    /** Gap between peers */
    this.gap = 10;
    /** Config object */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  connectedCallback() {
    this.screenSharePeersChanged(this.screenSharePeers);
    this.pluginsChanged(this.plugins);
  }
  screenSharePeersChanged(screenSharePeers = []) {
    if (this.activeTab == null && screenSharePeers.length > 0) {
      this.activeTab = { type: 'screenshare', peer: screenSharePeers[0] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  pluginsChanged(plugins) {
    if (plugins.length > 0) {
      const lastIndex = plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: plugins[lastIndex] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  revalidateActiveTab() {
    if (this.activeTab != null) {
      if (this.activeTab.type === 'screenshare') {
        const { peer } = this.activeTab;
        if (!this.screenSharePeers.some((p) => p.id === peer.id)) {
          this.reassignActiveTab();
        }
      }
      else {
        const { plugin } = this.activeTab;
        if (!this.plugins.some((p) => p.id === plugin.id)) {
          this.reassignActiveTab();
        }
      }
    }
  }
  reassignActiveTab() {
    if (this.screenSharePeers.length > 0) {
      this.activeTab = { type: 'screenshare', peer: this.screenSharePeers[0] };
    }
    else if (this.plugins.length > 0) {
      const lastIndex = this.plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: this.plugins[lastIndex] };
    }
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null, h("main", null, h("div", { class: "active-tab" }, this.activeTab &&
      (this.activeTab.type === 'screenshare' ? (h(Render, { element: "dyte-screenshare-view", defaults: defaults, props: {
          key: this.activeTab.peer.id,
          peer: this.activeTab.peer,
        }, childProps: { peer: this.activeTab.peer, isScreenShare: true }, deepProps: true })) : (h(Render, { element: "dyte-plugin-main", defaults: defaults, props: { key: this.activeTab.plugin.id, plugin: this.activeTab.plugin } })))), h("div", { class: "switcher" }, h("div", { class: "list scrollbar" }, this.screenSharePeers.map((peer) => {
      const name = formatName(peer.name);
      return (h("dyte-button", { title: `${name}'s Screen Share`, key: peer.id, kind: "icon", class: {
          active: this.activeTab.type === 'screenshare' && this.activeTab.peer.id === peer.id,
        }, onClick: () => (this.activeTab = { type: 'screenshare', peer }) }, h("div", { class: "col-center" }, h("dyte-icon", { icon: this.iconPack.share_screen_person }), h("span", { class: "name" }, peer.id === this.meeting.self.id ? 'You' : shorten(name, 6)))));
    }), this.plugins.map((plugin) => (h("dyte-button", { title: plugin.name, key: plugin.id, kind: "icon", class: {
        active: this.activeTab.type === 'plugin' && this.activeTab.plugin.id === plugin.id,
      }, onClick: () => (this.activeTab = { type: 'plugin', plugin }) }, h("div", { class: "col-center" }, h("img", { src: plugin.picture }), h("span", { class: "name" }, shorten(plugin.name, 6))))))))), h("aside", null, h("div", { class: "list scrollbar" }, this.peers.map((peer) => (h(Render, { element: "dyte-peer-view", defaults: defaults, props: { key: peer.id, peer, size: 'sm' }, childProps: { peer, size: 'sm' }, deepProps: true })))))));
  }
  static get watchers() { return {
    "screenSharePeers": ["screenSharePeersChanged"],
    "plugins": ["pluginsChanged"]
  }; }
};
DyteFullGrid.style = dyteFullGridCss;

export { DyteFullGrid as dyte_full_grid };
