import { r as registerInstance, c as createEvent, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dyteParticipantsToggleCss = ":host{display:block}";

const DyteParticipantsToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.participantsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
  }
  statesChanged(states) {
    if (states != null) {
      this.participantsActive = this.states.activeSidebar && this.states.sidebar === 'participants';
    }
  }
  toggleParticipantsTab() {
    this.participantsActive = !(this.states.activeSidebar && this.states.sidebar === 'participants');
    this.stateUpdate.emit({
      activeSidebar: this.participantsActive,
      sidebar: this.participantsActive ? 'participants' : 'none',
    });
  }
  render() {
    const text = this.t('participants');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { class: { active: this.participantsActive }, size: this.size, onClick: () => this.toggleParticipantsTab(), icon: this.iconPack.participants, label: text })));
  }
  static get watchers() { return {
    "states": ["statesChanged"]
  }; }
};
DyteParticipantsToggle.style = dyteParticipantsToggleCss;

export { DyteParticipantsToggle as dyte_participants_toggle };
