import { r as registerInstance, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';
import { l as loglevel } from './logger-5472d03c.js';

const dyteScreenShareToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const deviceCanScreenShare = () => {
  return (typeof navigator !== 'undefined' &&
    typeof navigator.mediaDevices !== 'undefined' &&
    'getDisplayMedia' in navigator.mediaDevices);
};
const DyteScreenShareToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.screenShareEnabled = false;
    this.canScreenShare = false;
  }
  connectedCallback() {
    if (!deviceCanScreenShare()) {
      loglevel.error('[dyte-screenshare-toggle] Device does not support screensharing.');
    }
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.screenShareListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('screenShareUpdate', this.screenShareListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canScreenShare =
        deviceCanScreenShare() && meeting.self.permissions.produceScreenshare.allow;
      this.screenShareEnabled = self.screenShareEnabled;
      this.screenShareListener = ({ screenShareEnabled }) => {
        this.screenShareEnabled = screenShareEnabled;
      };
      self.addListener('screenShareUpdate', this.screenShareListener);
    }
  }
  toggleScreenShare() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canScreenShare) {
      return;
    }
    if (self.screenShareEnabled) {
      self.disableScreenShare();
    }
    else {
      self.enableScreenShare();
    }
  }
  render() {
    if (!this.canScreenShare) {
      return null;
    }
    const text = this.t(this.screenShareEnabled ? 'share_screen_stop' : 'share_screen_start');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': this.screenShareEnabled,
      }, onClick: () => this.toggleScreenShare(), icon: this.screenShareEnabled
        ? this.iconPack.share_screen_stop
        : this.iconPack.share_screen_start, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteScreenShareToggle.style = dyteScreenShareToggleCss;

export { DyteScreenShareToggle as dyte_screen_share_toggle };
